## install packages
install.packages(c("stringr","data.table","nnet","reshape2","ggplot2","GGally","caret"))

## zaladuj pakiety
library(stringr)
library(data.table)
library(nnet)
library(reshape2)
library(ggplot2)
library(GGally)
library(caret)

## change the path
## change "\" to "/"
setwd("~/../Dropbox/Projects/foldername/")


#data loading
data4=fread("data/filename.csv")
data4=data4[!(is.na(data4$NAME)|data4$NAME==""),] #deletes empty lines


#changes "," to "."
data4$DUR_num=as.numeric(as.character(str_replace_all(data4$DUR,",",".")))
data4$COG_num=as.numeric(as.character(str_replace_all(data4$COG,",",".")))
data4$UNVOI_num=as.numeric(as.character(str_replace_all(data4$UNVOI,",",".")))
data4$DUR=NULL
data4$COG=NULL
data4$UNVOI=NULL


#### output graphs ####
dir.create("output_final_2/") #creates folder


dataPlot=data4 # data copying
colnames(dataPlot)
colnames(dataPlot)[27:29]<-c("DUR","COG","UNVOI") # change column names 

## ggplot 
plot=ggplot(data=melt(dataPlot[!dataPlot$IMPRES=="",c("DUR","UNVOI","COG","IMPRES")]), 
            aes(x=IMPRES,group=IMPRES,y=value))+
  facet_grid(variable~.,scales = "free_y")+ 
  geom_boxplot(size=1.2)+ 
  theme_bw()+ 
  scale_x_discrete("",labels=c("retenidas","debilitadas"))+
  scale_y_continuous("valor")

## ggsave 
ggsave(plot,filename ="output_final_2/plot1.png",width=4,height=6)
ggsave(plot,filename="output_final_2/plot1.pdf",width=4,height=6)


plot=ggplot(data=dataPlot,aes(x=DUR,y=..density..,fill=factor(1)))+
  geom_density(alpha=0.8,size=1.5)+ 
  theme_bw()+
  theme(legend.position = 'none')+ 
  scale_y_continuous("densidad")+
  scale_fill_manual(values = "#a6bddb") 
ggsave(plot,filename="output_final_2/plot2.png",width=4,height=3)
ggsave(plot,filename="output_final_2/plot2.pdf",width=4,height=3)

plot=ggplot(data=dataPlot,aes(x=COG,y=..density..,fill=factor(1)))+
  geom_density(alpha=0.8,size=1.5)+theme_bw()+theme(legend.position = 'none')+
  scale_y_continuous("densidad")+scale_fill_manual(values = "#bdbdbd")
ggsave(plot,filename="output_final_2/plot3.png",width=4,height=3)
ggsave(plot,filename="output_final_2/plot3.pdf",width=4,height=3)

plot=ggplot(data=dataPlot,aes(x=UNVOI,y=..density..,fill=factor(1)))+
  geom_density(alpha=0.8,size=1.5)+theme_bw()+theme(legend.position = 'none')+
  scale_y_continuous("densidad")+scale_fill_manual(values = "#bdbdbd")
ggsave(plot,filename="output_final_2/plot4.png",width=4,height=3)
ggsave(plot,filename="output_final_2/plot4.pdf",width=4,height=3)


data_out=dataPlot[,c("DUR","COG", "UNVOI")] 
plot=ggpairs(data_out[data_out$DUR<0.4,])+theme_bw() 
ggsave(plot,file="output_final_2/plot5.png",width=5,height=5)
ggsave(plot,file="output_final_2/plot5.pdf",width=5,height=5)


## statistical tests - perceptual classification vs. acoustic parameters

## t-test
t.test(dataPlot$DUR[dataPlot$IMPRES=="s"],dataPlot$DUR[dataPlot$IMPRES=="w"]) 
t.test(dataPlot$COG[dataPlot$IMPRES=="s"],dataPlot$COG[dataPlot$IMPRES=="w"])
t.test(dataPlot$UNVOI[dataPlot$IMPRES=="s"],dataPlot$UNVOI[dataPlot$IMPRES=="w"])


## non-parametric test
wilcox.test(dataPlot$DUR[dataPlot$IMPRES=="s"],dataPlot$DUR[dataPlot$IMPRES=="w"])
wilcox.test(dataPlot$COG[dataPlot$IMPRES=="s"],dataPlot$COG[dataPlot$IMPRES=="w"])
wilcox.test(dataPlot$UNVOI[dataPlot$IMPRES=="s"],dataPlot$UNVOI[dataPlot$IMPRES=="w"])


## classifiers ####

## complete model
model=multinom(data=data4[!data4$IMPRES=="",], 
               IMPRES~DUR_num+COG_num+UNVOI_num)

# classifier's efficiency
obsv=factor(data4$IMPRES[!data4$IMPRES==""]) 
pred=predict(model,type="class") 
confusionMatrix(obsv,pred) 

# single variable models
model=multinom(data=data4[!data4$IMPRES=="",], IMPRES~DUR_num)
obsv=factor(data4$IMPRES[!data4$IMPRES==""])
pred=predict(model,type="class")
confusionMatrix(obsv,pred)

model=multinom(data=data4[!data4$IMPRES=="",], IMPRES~COG_num)
obsv=factor(data4$IMPRES[!data4$IMPRES==""])
pred=predict(model,type="class")
confusionMatrix(obsv,pred)

model=multinom(data=data4[!data4$IMPRES=="",], IMPRES~UNVOI_num)
obsv=factor(data4$IMPRES[!data4$IMPRES==""])
pred=predict(model,type="class")
confusionMatrix(obsv,pred)


